{% extends widget.get_base_template %}

{% block content %}
<div class="panel-group" id="accordion_{{ widget.fe_identifier }}">
  {% for item in items %}
  <div class="panel panel-default">
    <div class="panel-heading">
      <h4 class="panel-title">
        <a data-toggle="collapse" data-parent="#accordion_{{ widget.fe_identifier }}" href="#accordion_{{ widget.fe_identifier }}_{{ forloop.counter0 }}">{{ item.title }}</a>
      </h4>
    </div>
    <div id="accordion_{{ widget.fe_identifier }}_{{ forloop.counter0 }}" class="panel-collapse collapse{% if forloop.first %} in{% endif %}">
      <div class="panel-body">
      {% block item_content %}
      {% include widget.get_item_template with item=item %}
        {% endblock %}
      </div>
    </div>
  </div>
  {% endfor %}
</div>
{% endblock %}
