{% extends widget.get_base_template %}

{% load i18n %}

{% block content %}
<ul class="vertical">
	{% for header in headers %}
	<li {% if forloop.last %}class="last"{% endif %}><a {% if forloop.last %}class="last"{% endif %} href="#{{ header.options.label|slugify }}">{{ header.options.label }}</a></li>
	{% endfor %}
</ul>
{% endblock %}
