$accordionBorderColor: #e5e5e5;

.nav_accordion {
  background-color: #f9f9f9;
  color: #6e6e6e;
  margin: 0px 0px;
  dt, dd {
    padding: 10px 0 10px 0;
    line-height: 18px;
    h4 {
      border: 1px solid #bbbbbb;
      border-right: 0;
      border-bottom: 0;
      background-color: #f0f0f0;
      background-repeat: no-repeat;
      background-position: 96% center;
      background-image: url("../img/right_droparrow.png");
      padding: 10px 0 10px 0;
      line-height: 16px;
      margin-top: 0;
      margin-bottom: 0;
      color: #6e6e6e;
      font-weight: bold;
      text-rendering: optimizelegibility;
      max-width: 217px;
      padding-right: 16px;
      cursor: pointer;
      div {
        color: #6e6e6e;
        font-size: 14px;
        margin: 0 0 0 14px;
        display: block;
        font-weight: bold;
        outline: none;
        overflow: hidden;
        text-overflow: ellipsis;
        max-width: 177px; } }
    h4.active {
      border-bottom: 1px solid #bbbbbb;
      background-image: url("../img/drop_arrow.png"); }
    a {
      color: #6e6e6e;
      font-size: 16px;
      margin: 0 0 0 14px;
      padding: 0;
      display: block;
      font-weight: bold;
      outline: none;
      text-decoration: none; }
    ul {
      list-style: none outside none;
      margin: 10px 0 0;
      padding: 0;
      width: 222px; }
    li {
      a {
        width: 209px;
        padding: 10px;
        display: block;
        line-height: 18px;
        margin-left: 20px;
        font-weight: normal;
        font-size: 13px; }
      a.active {
        background: white;
        border-top: 2px solid $accordionBorderColor;
        border-left: 4px solid #d93c27;
        border-bottom: 2px solid $accordionBorderColor;
        margin-left: 18px;
        border-radius: 5px 0 0 5px; }
      a:last-child {
        margin-bottom: 8px; } } }
  dd {
    padding: 0;
    margin-left: 9px;
    font-size: 12px; }
  dt {
    border-top: 1px solid #bbbbbb;
    background-color: $accordionBorderColor;
    background-repeat: no-repeat;
    background-position: 96% center;
    background-image: url("../img/right_droparrow.png");
    padding-right: 16px;
    max-width: 231px;
    cursor: pointer;
    div {
      color: #6e6e6e;
      font-size: 14px;
      margin: 0 0 0 14px;
      padding: 0;
      font-weight: bold;
      outline: none;
      overflow: hidden;
      text-overflow: ellipsis;
      max-width: 201px; } }
  dt.active {
    background-image: url("../img/drop_arrow.png"); }
  dt:first-child {
    border-top: 0; }
  dt a {
    text-decoration: none; } }
