{% load i18n %}

{% if widget.region == 'col3' %}
<div class="btn-group">
  <a class="leonardo-widget-dnd-handle btn btn-box-tool btn-success btn-xs"><i class="fa fa-arrows"></i></a>
</div>
{% endif %}
<div class="btn-group">
  <button data-toggle="dropdown" class="btn btn-box-tool btn-info btn-xs dropdown-toggle"><i class="fa fa-wrench"></i></button>
  <ul role="menu" class="dropdown-menu">
    {% for action in request.LEONARDO_CONFIG.widget_actions %}
      {% include action %}
    {% endfor %}
  </ul>
</div>
