{% extends "leonardo/common/_modal_form.html" %}

{% load url from future %}
{% load crispy_forms_tags i18n %}

{% block modal-header %}{{ modal_header }}{% endblock %}

{% block modal-body %}

<iframe src="{{ url }}" width="100%" height="600px"></iframe>

{% endblock %}

{% block modal-footer %}
  <a href="#" class="btn btn-default" data-dismiss="modal">{% trans "Close" %}</a>
{% endblock %}
