{% extends widget.get_base_template %}

{% load thumbnail %}

{% block content %}
{% if widget.source == 'youtube' %}
<object width="100%" height="100%">
	<param name="movie" value="http://www.youtube.com/v/{{ widget.source_id.v }}&hl=en&fs=1&"></param>
	<param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param>
	<embed src="http://www.youtube.com/v/{{ widget.source_id.v }}&hl=en&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="100%" height="100%"></embed>
</object>
{% endif %}
{% if widget.source == 'vimeo' %}
<object width="100%" height="100%">
	<param name="movie" value="http://www.youtube.com/v/{{ widget.source_id.v }}&hl=en&fs=1&"></param>
	<param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param>
	<embed src="http://www.youtube.com/v/{{ widget.source_id.v }}&hl=en&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="100%" height="100%"></embed>
</object>
{% endif %}
{% if widget.source == 'unknown' %}
<object width="100%" height="100%">
	<param name="movie" value="http://www.youtube.com/v/{{ widget.source_id.v }}&hl=en&fs=1&"></param>
	<param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param>
	<embed src="http://www.youtube.com/v/{{ widget.source_id.v }}&hl=en&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="100%" height="100%"></embed>
</object>
{% endif %}
{% endblock %}
