{% extends "leonardo/common/_modal_form.html" %}

{% load url from future %}
{% load crispy_forms_tags i18n %}

{% block form_id %}{{ form_id }}{% endblock %}
{% block form_action %}{{ url }}{% endblock %}

{% block modal-header %}{{ modal_header }}{% endblock %}

{% block modal-body %}

{{ body|safe }}
{% crispy form %}

{% endblock %}

{% block modal-footer %}
  <a href="#" class="btn btn-default" data-dismiss="modal">{% trans "Cancel" %}</a>
  <input class="btn btn-primary" type="submit" value="{{ form_submit|default:'Save' }}" />
{% endblock %}
