<div class="col-md-6">
  <h3>Inline Typography</h3>
  <p>
    <strong>strong</strong><br>
    <del>deleted</del><br>
    <em>emphasis</em>
  </p>
  <p>
    <a>anchor</a><br>
    <a href="#">a + href</a>
  </p>
  <p>
    <abbr title="extended abbr text should show when mouse over">abbr - extended text when mouseover.</abbr><br>
    <acronym title="extended acronym text should show when mouse over">acronym - extended text when mouseover.</acronym>
  </p>
  <address>
    address<br>
    Donald Duck<br>
    Disneyland
  </address>
</div>

<div class="col-md-6">
  <h3>Block Typography</h3>
  <pre>pre  space1
  pre  space1
  pre    space2
  pre    space2
  pre tab
  pre tab</pre>
  <p><code>Not indented
    indent1
    indent1
    indent2
    indent3</code></p>
  <p><tt>
    This tt text should be monospaced
    and
    wrap as if
    one line of text
    even though the code has newlines, spaces, and tabs.
    It should be the same size as &lt;p&gt; text.
  </tt></p>
</div>