{% extends widget.get_base_template %}

{% block content %}
{% if title %}
<div class="section-heading">
  <h2 class="section-heading">{{ title|safe }}</h2>
</div>
{% else %}
<div class="section-heading">
  <h2 class="section-heading">{{ page.title|safe }}</h2>
</div>
{% endif %}
{% endblock %}
