
{% block items %}
{% for row in widget.get_rows %}
  <div class="row">
  {% for item in row %}
    <div class="col-md-{{ widget.columns_classes.0 }} col-xs-{{ widget.columns_classes.2 }} col-sm-{{ widget.columns_classes.1 }}">
      {% include widget.get_item_template with item=item %}
    </div>
  {% endfor %}
  </div>
{% endfor %}
{% endblock %}
