 {% load i18n %}


<div class="panel-body" style='padding-top: 5px;padding-bottom:0;'>
<div class="btn-group btn-group-justified" style="margin-bottom:5px;">
  <a class="btn btn-primary btn-sm btn-block ajax-modal" data-toggle="tooltip" title="{% trans 'Create Page' %}" href="{% url 'page_create' feincms_page.id %}"><i class="fa fa-plus"></i> {% trans 'Create' %}</a>
  <a class="btn btn-primary btn-sm btn-block ajax-modal" href="{% url 'page_delete' feincms_page.id %}" data-toggle="tooltip" title="{% trans 'Delete Page' %}"><i class="fa fa-minus"></i> {% trans 'Delete' %}</a>
</div>
<a class="btn btn-primary btn-sm btn-block ajax-modal" href="{% url 'page_update' feincms_page.id %}" data-toggle="tooltip" title="{% trans 'Edit Page' %}"><i class="fa fa-sliders"></i> {% trans 'Edit Page' %}</a>
<a class="btn btn-primary btn-sm btn-block ajax-modal" href="{% url 'page_mass_update' feincms_page.id %}" data-toggle="tooltip" title="{% trans 'Mass Update' %}"><i class="fa fa-pencil"></i> {% trans 'Mass Update' %}</a>
{% url 'admin:web_page_change' feincms_page.id as page_admin %}
<a class="btn btn-primary btn-sm btn-block ajax-modal" href="{% url 'modal_iframe' url=page_admin %}" data-toggle="tooltip" title="{% trans 'Page Admin' %}"><i class="fa fa-sliders"></i> {% trans 'Page Admin' %}</a>

<a class="btn btn-primary btn-sm btn-block" target="_blank" href="{% url 'admin:index' %}" data-toggle="tooltip" title="{% trans 'Admin' %}"><i class="fa fa-tachometer"></i> {% trans 'Admin' %}</a>
</div>
