{% load applicationcontent_tags i18n %}

{% include "base/widget/_base_begin.html" %}

<div id="{{ widget.fe_identifier }}" class="{{ widget.render_base_classes }} {% if widget.enter_effect_style != 'disabled' %}wow {{ widget.enter_effect_style }}{% endif %}"{% if widget.enter_effect_duration %}data-wow-duration="{{ widget.enter_effect_duration }}s"{% endif %} {% if widget.enter_effect_delay %}data-wow-delay="{{ widget.enter_effect_delay }}s"{% endif %} {% if widget.enter_effect_iteration %}data-wow-iteration="{{ widget.enter_effect_iteration }}"{% endif %} {% if widget.enter_effect_offset %}data-wow-offset="{{ widget.enter_effect_offset }}"{% endif %}>
  <div class="bs-callout {{ widget.render_content_classes }}">
    {% if request.frontend_editing %}
    <div class="widget-tools">
      {% include "base/widget/_edit.html" %}
    </div>
    {% endif %}
    {% block title %}
    {% if widget.label %}
    <a id="{{ widget.label|slugify }}"></a>
    <h2 class="widget-title"><span>{{ widget.label }}</span></h2>
    {% endif %}
    {% endblock %}
    {% block content %}{% endblock %}
  </div>
</div>

{% include "base/widget/_base_end.html" %}
