{% extends widget.get_base_template %}

{% block content %}
<h1>
  <a href="/"><b>{{ widget.site_title }}</b></a>
  {% if widget.tagline %}
  <span>{{ widget.tagline }}</span>
  {% endif %}
</h1>
{% endblock %}
