{% extends widget.get_base_template %}

{% load feincms_page_tags %}

{% block content %}

{% feincms_nav root level=level depth=1 as toplevel %}

{% for p in toplevel %}
{% if forloop.first %}<ul class="list-unstyled">{% endif %}
<li{% if p|is_equal_or_parent_of:current %} class="active"{% endif %}>
	<a href="{{ p.get_navigation_url }}">{{ p.title }}</a>
</li>
{% if forloop.last %}</ul>{% endif %}
{% endfor %}

{% if depth > 1  and widget.orientation == 'horizontal' %}


{% feincms_nav root level=level depth=1 as toplevel %}

{% for p in toplevel %}
{% if p|is_equal_or_parent_of:current %}

{% feincms_nav p level=level2 depth=1 as level %}


{% for p2 in level %}
{% if forloop.first %}<ul class="horizontal ui-helper-clearfix">{% endif %}
<li>
{% if p2.id == current.id %}
	<strong>{{ p2.title }}</strong>
{% else %}
	<a class="{% if forloop.first %}first {% endif %}{% if forloop.last %}last {% endif %}" href="{{ p2.get_navigation_url }}">{{ p2.title }}</a>
{% endif %}
</li>
{% if forloop.last %}</ul>{% endif %}
{% endfor %}

{% endif %}
{% endfor %}

{% endif %}

{% endblock %}
