
<div class="row">
  <div class="col-md-3 col-sm-3">
    <h3>1/4 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
  <div class="col-md-3 col-sm-3">
    <h3>1/4 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
  <div class="col-md-3 col-sm-3">
    <h3>1/4 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
  <div class="col-md-3 col-sm-3">
    <h3>1/4 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
</div>

<div class="row">
  <div class="col-md-4">
    <h3>1/3 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
  <div class="col-md-4">
    <h3>1/3 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
  <div class="col-md-4">
    <h3>1/3 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim.  </p>
  </div>
</div>

<div class="row">
  <div class="col-md-6 col-sm-6">
    <h3>1/2 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim elit hendrerit. Quisque tempus arcu vulputate metus convallis elementum.  </p>
  </div>
  <div class="col-md-6 col-sm-6">
    <h3>1/2 Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim elit hendrerit. Quisque tempus arcu vulputate metus convallis elementum.  </p>
  </div>
</div>

<div class="row">
  <div class="col-md-12">
    <h3>Full Width</h3>
    <p>about section Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas ullamcorper diam nec augue semper, in dignissim elit hendrerit. Quisque tempus arcu vulputate metus convallis elementum. Aenean rhoncus rutrum quam ut semper. Fusce ut eros quis metus ullamcorper commodo ut sit amet nisi. Cras mattis enim eu urna tristique posuere. In vitae adipiscing nulla. Phasellus purus eros, aliquam ac urna eget, dictum consequat turpis. Aliquam hendrerit odio ut placerat pharetra. Etiam quis auctor sapien. Praesent sed consectetur lorem, et gravida purus. </p>
  </div>
</div>
