{% extends widget.get_base_template %}

{% load i18n %}

{% block content %}
<div class="navbar-header">
  <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#top-nav">
    <span class="sr-only">{% trans "Toggle navigation" %}</span>
    <span class="icon-bar"></span>
    <span class="icon-bar"></span>
    <span class="icon-bar"></span>
  </button>
  {% if widget.logo %}
  <a class="navbar-brand" href="/"><img src="/static/img/logo.png" alt="logo" /></a>
  {% else %}
  <a class="navbar-brand" href="/">{{ widget.site_title }}
    {% if widget.tagline %}
    <span>{{ widget.tagline }}</span>
    {% endif %}
  </a>
  {% endif %}
</div>
{% endblock %}
