{%for message in messages%}
<ul class="messages">
    {% for message in messages %}
    <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message|safe }}</li>
    {% endfor %}
</ul>
{% endfor %}