{% extends widget.get_base_template %}

{% load i18n feincms_page_tags %}

{% block content %}
{% if widget.link == 'text' %}
<ul class="pager">
  {% if prev %}
  <li class="previous"><a href="{{ prev.get_absolute_url }}">← {% trans "prev" %}</a></li>
  {% else %}
  <li class="previous disabled"><a href="#">← {% trans "prev" %}</a></li>
  {% endif %}
  {% if next %}
  <li class="next"><a href="{{ next.get_absolute_url }}">{% trans "next" %} →</a></li>
  {% else %}
  <li class="next disabled"><a href="#">{% trans "next" %} →</a></li>
  {% endif %}
</ul>
{% else %}
<ul class="pager">
  {% if prev %}
  <li class="previous"><a href="{{ prev.get_absolute_url }}">{{ prev.title }}</a></li>
  {% else %}
  <li class="previous disabled"><a href="#">{{ prev.title }}</a></li>
  {% endif %}
  {% if next %}
  <li class="next"><a href="{{ next.get_absolute_url }}">{{ next.title }}</a></li>
  {% else %}
  <li class="next disabled"><a href="#">{{ next.title }}</a></li>
  {% endif %}
</ul>
{% endif %}
{% endblock %}