{% extends widget.get_base_template %}

{% load i18n %}

{% block content %}
<div id="{{widget.fe_identifier }}-video">
	<p>{% trans "Click link to get Flash Player or try to enable JavaScript and reload the page." %}</p>
	<p><a href="http://www.adobe.com/go/getflashplayer"><img src="http://www.adobe.com/images/shared/download_buttons/get_flash_player.gif" alt='{% trans "Get Adobe Flash player" %}' /></a></p>
</div>

<script type="text/javascript">
{{ widget.vars|safe }}

{{ widget.params|safe }}

{{ widget.attrs|safe }}

// dynamic embed of Flash, set the location of expressInstall if needed
swfobject.embedSWF('/media/files/{{ widget.file.file.name }}', "{{widget.fe_identifier }}-video", {{ widget.width|safe }},  {{ widget.height|safe }}, "{{ widget.version }}", "/static/lib/swfobject/expressinstall.swf", vars, params, attrs );
</script>
{% endblock %}

