
from .downloadlist.models import DownloadListWidget
from .downloaditem.models import DownloadItemWidget
from .internetvideo.models import InternetVideoWidget
from .mediagallery.models import MediaGalleryWidget
from .pdfdocument.models import PdfDocumentWidget

from .flashobject.models import FlashObjectWidget

from .simpleimage.models import SimpleImageWidget
from .simplevideo.models import SimpleVideoWidget

from .vectorgraphics.models import VectorGraphicsWidget
