{% load i18n %}

<div class="col-md-12">
  <h1>{% trans "Largest Heading" %}: Lorem ipsum dolor sit amet</h1>
  <h2>{% trans "2nd Largest Heading" %}: Lorem ipsum dolor sit amet, consectetur elit</h2>
  <h3>{% trans "3rd Largest Heading" %}: Lorem ipsum dolor sit amet, consectetur adipisicing elit</h3>
  <h4>{% trans "3rd Smallest Heading" %}: Lorem ipsum dolor sit amet, consectetur adipisicing elit adipis</h4>
  <h5>{% trans "2nd Smallest Heading" %}: Lorem ipsum dolor sit amet, consectetur adipisicing elit adipisicing elit adipisicing elit</h5>
  <h6>{% trans "Smallest Heading" %}: Lorem ipsum dolor sit amet, consectetur adipisicing elit adipisicing elit adipisicing elit</h6>
</div>
