<!DOCTYPE html>
{% load leonardo_tags feincms_page_tags branding i18n %}
<html>
  {% include "_header.html" %}
  <body id="{% block body_id %}main_content{% endblock %}" ng-app='hz' class="skin-blue">
    {% include "horizon/_messages.html" %}
    <div class="wrapper">
      <header>
        <div class="{{ page.get_layout_class }}">
          {% feincms_render_region feincms_page "header" request %}
        </div>
      </header>
      <div id="toolbar">
        <div class="{{ page.get_layout_class }}">
          {% feincms_render_region feincms_page "toolbar" request %}
        </div>
      </div>
      <div id="main">
        <div class="{{ page.get_layout_class }}">
          <aside class="col1 {% get_col_classes feincms_page 'col1' %}">
            {% feincms_render_region feincms_page "col1" request %}
            {% render_region_tools feincms_page "col1" request %}
          </aside>
          <section class="col3 {% get_col_classes feincms_page 'col3' %}">
            {% feincms_render_region feincms_page "col3" request %}
            {% render_region_tools feincms_page "col3" request %}
            {% block body_main %}{% endblock %}
          </section>
          <aside class="col2 {% get_col_classes feincms_page 'col2' %}">
            {% feincms_render_region feincms_page "col2" request %}
            {% render_region_tools feincms_page "col2" request %}
          </aside>
        </div>
      </div>
      <footer>
        <div class="{{ page.get_layout_class }}">
          {% feincms_render_region feincms_page "footer" request %}
        </div>
      </footer>
    </div>
    {% include "horizon/_scripts.html" %}
    {% feincms_render_region feincms_page "helper" request %}
    <div id="modal_wrapper"></div>
  </body>
</html>
