
{% extends "admin/media/base.html" %}
{% load i18n filermedia %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" type="text/css" href="{% filer_staticmedia_prefix %}css/admin_style.css" />
{% endblock %}