{% extends widget.get_base_template %}

{% block content %}
<div class="list-group">
  {% for child_page in items %}
  <a href="{{ child_page.get_absolute_url }}" class="list-group-item">
    {% include "widget/contextnavigation/_item.html" with item=child_page %}
  </a>
  {% endfor %}
</div>
{% endblock %}
