'''
    Original File Adapted from http://pub.mowser.com/wiki/Main/CodeExamples
    With a few additions by Moof
    http://minidetector.googlecode.com/svn/trunk/minidetector/search_strings.txt
'''

simple_devices = [
    'sony',
    'symbian',
    'nokia',
    'samsung',
    'mobile',
    'windows ce',
    'epoc',
    'opera mini',
    'nitro',
    'j2me',
    'midp',
    'cldc',
    'netfront',
    'mot',
    'up.browser',
    'up.link',
    'audiovox',
    'blackberry',
    'ericsson',
    'panasonic',
    'philips',
    'sanyo',
    'sharp',
    'portalmmm',
    'blazer',
    'avantgo',
    'danger',
    'palm',
    'series60',
    'palmsource',
    'pocketpc',
    'smartphone',
    'rover',
    'ipaq',
    'au-mic',
    'alcatel',
    'ericy',
    'up.link',
    'docomo',
    'vodafone',
    'wap1',
    'wap2',
    'plucker',
    'sec',
    'fennec',
    'google wireless transcoder',
]