{% extends widget.get_base_template %}

{% load i18n %}

{% block content %}
<ul class="navbar-collapse collapse nav navbar-nav{% if widget.align == 'right' %} navbar-right{% endif %}">
  {% if request.user.is_authenticated %}
  {% comment %}
  <li><a data-toggle="control-sidebar" href="#">{{ request.user.username }}</a></li>
  {% endcomment %}
  {% if request.frontend_editing %}
  <li><a href=".?frontend_editing=0">{% trans "Stop Editing" %}</a></li>
  {% else %}
  <li><a href=".?frontend_editing=1">{% trans "Start Editing" %}</a></li>
  {% endif %}
  <li><a href="{% url 'logout' %}?next={{ request.build_absolute_uri }}">{% trans "Sign Out" %}</a></li>
  {% else %}
  {% if widget.type == 2 %}
  <li><a class="ajax-modal" href="{% url 'login' %}?next={{ request.build_absolute_uri }}">{% trans "Sign In" %}</a></li>
  {% else %}
  <li><a href="{% url 'admin:login' %}">{% trans "Sign In" %}</a></li>
  {% endif %}
  {% endif %}
</ul>
{% endblock %}