{% load applicationcontent_tags i18n %}

{% include "base/widget/_base_begin.html" %}

<div id="{{ widget.fe_identifier }}" class="{{ widget.render_base_classes }} {% if widget.enter_effect_style != 'disabled' %}wow {{ widget.enter_effect_style }}{% endif %}"{% if widget.enter_effect_duration %}data-wow-duration="{{ widget.enter_effect_duration }}s"{% endif %} {% if widget.enter_effect_delay %}data-wow-delay="{{ widget.enter_effect_delay }}s"{% endif %} {% if widget.enter_effect_iteration %}data-wow-iteration="{{ widget.enter_effect_iteration }}"{% endif %} {% if widget.enter_effect_offset %}data-wow-offset="{{ widget.enter_effect_offset }}"{% endif %}>
  <div class="panel box box-solid {{ widget.render_content_classes }}">
    {% block title %}
    {% if widget.label or request.frontend_editing %}
    <div class="panel-heading box-header with-border">
      {% if widget.label %}
      <a id="{{ widget.label|slugify }}"></a>
      <h3 class="panel-title"><span>{{ widget.label }}</span></h3>
      {% endif %}
      {% if request.frontend_editing %}
      <div class="box-tools pull-right">
        {% include "base/widget/_edit.html" %}      
      </div>    
      {% endif %}
    </div>
    {% endif %}
    {% endblock %}
    <div class="panel-body box-body">
      {% block content %}{% endblock %}
    </div>
  </div>
</div>

{% include "base/widget/_base_end.html" %}
