{% extends "leonardo/common/_modal.html" %}
{% load i18n %}
{% load url from future %}

{% block form_id %}login_form{% endblock %}
{% block form_action %}{% url "login" %}?{{ redirect_field_name }}={{ redirect_field_value }}{% endblock %}

{% block modal-footer %}
<a href="#" class="btn btn-default" data-dismiss="modal">{% trans "Close" %}</a>
<input class="btn btn-primary pull-right" type="submit" value="{% trans "Login" %}" />
{% endblock %}
