{% extends widget.get_base_template %}

{% load i18n feincms_page_tags %}

{% block content %}
{% feincms_languagelinks for page as links all,excludecurrent,request=request %}
{% for key, name, link in links %}
    <a href="{% if link %}{{ link }}{% else %}/{{ key }}/{% endif %}">{% trans name %}</a>
{% endfor %}
{% endblock %}
