{% load i18n %}
{% load url from future %}

{% if edit %}
<div class="clearfix col-md-12 region-tools">
  <a href="{{ add_entry_url }}" class='btn btn-block btn-success ajax-modal' data-toggle="tooltip" data-placement="bottom" title="Add new entry" data-original-title="Add new entry">{% trans 'Add Entry' %}</a>
</div>
{% endif %}