{% extends widget.get_base_template %}

{% load feincms_page_tags %}

{% block content %}
{% feincms_nav root level=level depth=depth as toplevel %}
{% for page in toplevel %}
<a href="{{ page.get_navigation_url }}" class="btn{% if widget.orientation == 'vertical' %} btn-block{% endif %}{% if page|is_equal_or_parent_of:current %} btn-primary{% else %} btn-default{% endif %}">{{ page.title }}</a>
{% endfor %}
{% endblock %}