<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="description" content="{{ request.webcms_options.meta_description }}" />
<meta name="keywords" content="{{ request.webcms_options.meta_keywords }}" />
<meta name="robots" content="index,follow" />
<meta name="generator" content="Leonardo" />
<meta http-equiv="author" content="Michael Kutý, Aleš Komárek" />
