{% extends widget.get_base_template %}

{% load i18n leonardo_page_tags %}

{% block content %}
{% feincms_languagelinks for page as links all,excludecurrent,request=request %}
<ul class="navbar-collapse collapse nav navbar-nav navbar-right">
{% for key, name, link in links %}
    <li><a href="{% if link %}{{ link }}{% else %}/{{ key }}/{% endif %}">{% trans name %}</a></li>
{% endfor %}
</ul>
{% endblock %}
