{% extends widget.get_base_template %}

{% block content %}
<ul class="nav nav-tabs">
  {% for child_page in items %}
  <li{% if forloop.first %} class="active"{% endif %}><a data-toggle="tab" href="#tab_{{ widget.fe_identifier }}_{{ forloop.counter0 }}">{{ child_page.title }}</a></li>
  {% endfor %}
</ul>
<div class="tab-content">
  {% for child_page in items %}
  <div id="tab_{{ widget.fe_identifier }}_{{ forloop.counter0 }}" class="tab-pane{% if forloop.first %} active in{% endif %}">
    {% include "widget/contextnavigation/_item.html" with item=child_page %}
  </div>
  {% endfor %}
</div>
{% endblock %}
