{% extends "admin/change_form.html" %}
{% load i18n %}

{% block breadcrumbs %}
<div class="breadcrumbs">
   <a href="{% url 'admin:index' %}" title="{% trans "Go back to" %} {% trans "admin homepage" %}">{% trans "Home" %}</a>
    &rsaquo; <a href="{% url 'admin:app_list' app_label='media' %}" title="{% trans "Go back to" %} {% trans "Media" %}"> {% trans "Media" %}</a>
    {% comment %}
    {% for ancestor_folder in original.get_ancestors %}
    &rsaquo; <a href="{% url 'admin:media_folder_change' ancestor_folder.id.id %}" title="{% blocktrans with ancestor_folder.name as folder_name %}Go back to '{{ folder_name }}' folder{% endblocktrans %}">{{ ancestor_folder.name }}</a>
    {% endfor %}
    &rsaquo; {{ original.name }}
    {% endcomment %}
</div>
{% endblock %}

{% block content %}
<h1>{% trans "Add new" %} {% trans "folder" %}</h1>
<div id="content-main">
    <form id="folder_form" method="post" action="" enctype="multipart/form-data">
        {% csrf_token %}
        <div>
          <input type="hidden" value="1" name="_popup"/>
          {% if select_folder %}<input type="hidden" name="select_folder" value="1" />{% endif %}
          {% if new_folder_form.errors %}
            <p class="errornote">
            {% blocktrans count new_folder_form.errors|length as counter %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
            </p>
            {{ new_folder_form.non_field_errors }}
          {% endif %}
          <fieldset class="module aligned">
            <div class="form-row {% if new_folder_form.errors.name %}errors {% endif %}name">
              {{ new_folder_form.errors.name.as_ul }}
              <div>
              {% for field in new_folder_form %}
                <label class="required" for="id_{{ field.name }}">{{ field.label }}:</label>{{ field }}
              {% endfor %}
              </div>
            </div>
          </fieldset>
        <div style="overflow: auto;" class="submit-row">
            <input type="submit" name="_save" class="default" value="{% trans "Scan" %}"/>
        </div>
        <script type="text/javascript">document.getElementById("id_name").focus();</script>
        </div>
    </form>
</div>

        
 <br class="clear"/>
{% endblock %}