{% load i18n filer_admin_tags %}{% spaceless %}
{% if object %}
    {% trans 'Folder' %}: <span id="{{ span_id }}">{{ object.pretty_logical_path }}</span>
{% else %}
    {% trans 'Folder' %}: <span id="{{ span_id }}">{% trans 'none selected' %}</span>
{% endif %}
<a href="{{ lookup_url }}" class="related-lookup" id="lookup_id_{{ lookup_name }}" title="{% trans 'Lookup' %}" onclick="return showRelatedObjectLookupPopup(this);">
	<img src="{% admin_icon_base %}icon_searchbox.png" width="16" height="16" alt="{% trans 'Lookup' %}" />
</a>
<img id="{{ clear_id }}" src="{% admin_icon_base %}icon_deletelink.gif" width="10" height="10" alt="{% trans 'Clear' %}" title="{% trans 'Clear' %}"{% if not object %} style="display: none;"{% endif %} />
<br />
{{ hidden_input }}
<script type="text/javascript">django.jQuery("#{{ id }}").hide();
django.jQuery("#{{ id }}_clear").click(function(){
    django.jQuery("#{{ id }}").removeAttr("value");
    django.jQuery("#{{ foldid }}").attr("src", "{{ noimg }}");
    django.jQuery("#{{ descid }}").html("");
});
django.jQuery(document).ready(function(){
    var plus = django.jQuery("#add_{{ id }}");
    if (plus.length){
        plus.remove();
    }
});
</script>
{% endspaceless %}
