{% extends "horizon/client_side/template.html" %}
{% load i18n horizon %}

{% block id %}spinner-modal{% endblock %}

{% block template %}{% spaceless %}{% jstemplate %}

    <div style="position: absolute; left: 50%; top: 50%;">
        <div style="position: relative; left: -50%; top: -50px;">
          <div class="spinner"></div>
        </div>
    </div>

{% endjstemplate %}{% endspaceless %}{% endblock %}