<script type="text/javascript">
	$(document).ready(function(){
		$('div.form-row label[for$=composers]').parent().css({'display':'none'});
		$('div.form-row label[for$=components]').parent().css({'display':'none'});
	});
</script> 
 
