
<div class="col-md-4">
  <h3>Simple Table</h3>

<table class="table">
  <thead>
    <tr>
      <th>#</th>
      <th>First Name</th>
      <th>Last Name</th>
      <th>Username</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>1</td>
      <td>Mark</td>
      <td>Otto</td>
      <td>@mdo</td>
    </tr>
    <tr>
      <td>2</td>
      <td>Jacob</td>
      <td>Thornton</td>
      <td>@fat</td>
    </tr>
    <tr>
      <td>3</td>
      <td>Larry</td>
      <td>the Bird</td>
      <td>@twitter</td>
    </tr>
  </tbody>
</table>

</div>

<div class="col-md-8">
  <h3>Stripped Table</h3>

<table class="table table-striped">
  <thead>
    <tr>
      <th>Product Type</th>
      <th>PC</th>
      <th>PC</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>Product Type</th>
      <td>PC</td>
      <td>PC</td>
    </tr>
    <tr>
      <th>Price (excl. tax)</th>
      <td>£200.00</td>
      <td>£200.00</td>
    </tr>
    <tr>
      <th>Price (incl. tax)</th>
      <td>£200.00</td>
      <td>£200.00</td>
    </tr>
    <tr>
      <th>Tax</th>
      <td>£0.00</td>
      <td>£0.00</td>
    </tr>
    <tr>
      <th>Availability</th>
      <td>In stock (449 available)</td>
      <td>In stock (449 available)</td>
    </tr>
    <tr>
      <th>velikost</th>
      <td>velikost</td>
      <td>velikost</td>
    </tr>
    <tr>
      <th>Number of reviews</th>
      <td>0</td>
      <td>0</td>
    </tr>
  </tbody>
</table>

</div>