{% extends "admin/change_form.html" %}
{% load i18n admin_modify filermedia %}

{% block extrahead %}{{ block.super }}
{% endblock %}

{% block breadcrumbs %}
{% with original as instance %}
{% include "admin/media/breadcrumbs.html" %}
{% endwith %}
{% endblock %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" type="text/css" href="{% filer_staticmedia_prefix %}css/admin_style.css" />
{% endblock %}

{% block coltype %}colMS{% endblock %}

{% block after_field_sets %}
    {% if is_popup and select_folder %}<input type="hidden" name="select_folder" value="1" />{% endif %}
{% endblock %}

{% block sidebar %}
<div id="content-related">
	{% block file_sidebar %}
		{% with original.duplicates as duplicates %}
			{% if duplicates %}
				<h3>{% trans 'duplicates' %}</h3>
				<ul>
					{% for duplicate in duplicates %}<li><a href="{{ duplicate.get_admin_url_path }}">{{ duplicate }}</a></li>{% endfor %}
				</ul>
			{% endif %}
		{% endwith %}
	{% endblock %}
</div>
{% endblock %}
