{% load i18n %}
<a class='svg_edit_link' href='{{editor_page_url}}?url={{svg.file.url}}&svgid={{svg.id}}&dimensions={{svg.height}},{{svg.width}}&svgmodel={{svg.svgmodel}}'>{% trans "Edit on site" %}</a>