{% extends "leonardo/common/modal.html" %}
{% load i18n %}

{% block title %}{% trans "Login" %}{% endblock %}

{% block page_header %}
{% include "horizon/common/_page_header.html" with title=_("Login") %}
{% endblock %}

{% block body_main %}
{% include "auth/_login.html" %}
{% endblock %}