<div class="col-md-6">
  <h3>Buttons</h3>
  <button class="btn  btn-custom btn-lg" type="button">Custom</button>
  <button class="btn btn-default btn-lg" type="button">Default</button>
  <button class="btn btn-primary btn-lg" type="button">Primary</button>
  <button class="btn btn-success btn-lg" type="button">Success</button>
  <button class="btn btn-info btn-lg" type="button">Info</button>
  <button class="btn btn-warning btn-lg" type="button">Warning</button>
  <button class="btn btn-danger btn-lg" type="button">Danger</button>
  <br><br>
  <button class="btn  btn-custom" type="button">Custom</button>
  <button class="btn btn-default" type="button">Default</button>
  <button class="btn btn-primary" type="button">Primary</button>
  <button class="btn btn-success" type="button">Success</button>
  <button class="btn btn-info" type="button">Info</button>
  <button class="btn btn-warning" type="button">Warning</button>
  <button class="btn btn-danger" type="button">Danger</button>
  <br><br>
  <button class="btn btn-sm btn-custom" type="button">Custom</button>
  <button class="btn btn-sm btn-default" type="button">Default</button>
  <button class="btn btn-sm btn-primary" type="button">Primary</button>
  <button class="btn btn-sm btn-success" type="button">Success</button>
  <button class="btn btn-sm btn-info" type="button">Info</button>
  <button class="btn btn-sm btn-warning" type="button">Warning</button>
  <button class="btn btn-sm btn-danger" type="button">Danger</button>
  <br><br>
  <button class="btn btn-custom btn-lg" type="button">
    <i class="fa fa-star"></i> Star
  </button>
  <button class="btn btn-default btn-lg" type="button">
    <i class="fa fa-star"></i> Star
  </button>
  <button class="btn btn-primary" type="button">
    <i class="fa fa-star"></i> Primary
  </button>
  <button class="btn btn-success btn-sm" type="button">
    <i class="fa fa-star"></i> Star
  </button>
</div>

<div class="col-md-6">
  <h3>Alerts</h3>
  <div role="alert" class="alert alert-success"><strong>Well done!</strong> You successfully read this important alert message.</div>
  <div role="alert" class="alert alert-info"><strong>Heads up!</strong> This alert needs your attention, but not important.</div>
  <div role="alert" class="alert alert-warning"><strong>Warning!</strong> Better check yourself, you're not looking too good.</div>
  <div role="alert" class="alert alert-danger"><strong>Oh snap!</strong> Change a few things up and try submitting again.</div>
</div>
