
import warnings

from leonardo.forms.fields import *

warnings.warn('leonardo.fields is obsolete'
              ' location use leonardo.forms instead'
              'This location is only in migrations now')
