
{% load applicationcontent_tags %}

{% fragment request "_breadcrumbs" append %}{% block breadcrumbs %}{% endblock %}{% endfragment %}
{% fragment request "_head_title" %}{% block head_title %}{% endblock %}{% endfragment %}
{% fragment request "_page_title" append %}{% block page_title %}{% endblock %}{% endfragment %}
{% fragment request "_page_subtitle" %}{% block page_subtitle %}{% endblock %}{% endfragment %}
{% fragment request "extra_meta" %}{% block meta %}{% endblock %}{% endfragment %}

{% fragment request "current_brand" %}{% block current_brand %}{% endblock %}{% endfragment %}
{% fragment request "current_product" %}{% block current_product %}{% endblock %}{% endfragment %}
{% fragment request "current_category" %}{% block current_category %}{% endblock %}{% endfragment %}

{% fragment request "sidebar" %}{% block sidebar %}{% endblock %}{% endfragment %}
{% block content %}
{% include "base/messages.html" %}
{{ content|safe }}
{% endblock %}
