
@media screen and (min-width: 768px) {
  .modal-dialog {
    left: 0%!important;
  }
  .row-md-1 > div { height: 60px; }
  .row-md-2 > div { height: 120px; }
  .row-md-3 > div { height: 180px; }
  .row-md-4 > div { height: 240px; }
  .row-md-5 > div { height: 300px; }
  .row-md-6 > div { height: 360px; }
  .row-md-7 > div { height: 420px; }
  .row-md-8 > div { height: 480px; }
  .row-sm-9 > div { height: 540px; }
  .row-sm-10 > div { height: 600px; }
  .row-sm-11 > div { height: 660px; }
  .row-sm-12 > div { height: 720px; }
}

@media screen and (max-width: 768px) {
  .modal-dialog {
    left: 0%!important;
  }
  .row-sm-1 > div { height: 60px; }
  .row-sm-2 > div { height: 120px; }
  .row-sm-3 > div { height: 180px; }
  .row-sm-4 > div { height: 240px; }
  .row-sm-5 > div { height: 300px; }
  .row-sm-6 > div { height: 360px; }
  .row-sm-7 > div { height: 420px; }
  .row-sm-8 > div { height: 480px; }
  .row-sm-9 > div { height: 540px; }
  .row-sm-10 > div { height: 600px; }
  .row-sm-11 > div { height: 660px; }
  .row-sm-12 > div { height: 720px; }
}


.col-md-0 { 
  display: none;
}

.no-gutter > [class*="col-"] {
  padding-left: 0;
  padding-right: 0;
}

.region-tools {
  padding: 5px 0;
}

.widget-tools {
  position: absolute;
  top: 5px;
  right: 5px;
  z-index:400;
}

.leonardo-widget .leonardo-widget .widget-tools {
  right: 15px;
  z-index:401;
}

.leonardo-widget .leonardo-widget .leonardo-widget .widget-tools {
  right: 25px;
  z-index:402;
}

.col1, .col2, .col3 {
  padding-left:0!important;
  padding-right:0!important;
}

.equal, .equal > div[class*='col-'] {  
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    flex:1 1 auto;
}

.nav-tabs {
  margin-bottom: 15px!important;
}

.modal {
  overflow: auto;
  margin-bottom: 2.5%;
  top: 0!important;
  outline: none;
}

input[id=search-input]:focus {
  width: 220px!important;
  background-color: #fff;
  border-color: #6dcff6;
  z-index: 9900;
}
#search-button {
  z-index: 9900;
}
/* search input field */
input[id=search-input] {
  width: 100px!important;
  border: solid 1px #ccc;
  padding: 9px 10px 9px 32px;
  width: 55px;
  
  -webkit-border-radius: 10em;
  -moz-border-radius: 10em;
  border-radius: 10em;
  
  -webkit-transition: all .5s;
  -moz-transition: all .5s;
  transition: all .5s;
}
