{% extends widget.get_base_template %}

{% load i18n %}
{% load leonardo_tags %}

{% block content %}

<form action="{% url 'haystack_search' 'leonardo.module.search.apps.search' %}" method="get" class="navbar-collapse collapse navbar-form navbar-left" role="search">
  <div class="input-group">
	<input value="{{ query }}" type="text" class="form-control"  name="q" id="search_keywords" />
  	<span class="input-group-btn">
  		<button id='search-button' class="btn btn-default" type="submit">{% trans "Search" %}&nbsp;<i class=" glyphicon glyphicon-search" aria-hidden="true"></i></button>
  	</span>
  </div>
</form>
{% endblock %}
