
from .icon.models import IconWidget
from .application.models import ApplicationWidget
from .markuptext.models import MarkupTextWidget
from .feedreader.models import FeedReaderWidget
from .pagetitle.models import PageTitleWidget
from .table.models import TableWidget
from .siteheading.models import SiteHeadingWidget
from .htmltext.models import HtmlTextWidget
