{% extends "admin/media/change_form.html" %}
{% load i18n admin_modify %}


{% block object-tools %}
{% if change %}{% if not is_popup %}
  <ul class="object-tools">
    {#<li><a href="export/">{% trans "Export" %}</a></li>#}
    <li><a href="history/" class="historylink">{% trans "History" %}</a></li>
  {% if has_absolute_url %}<li><a href="../../../r/{{ content_type_id }}/{{ object_id }}/" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}
  </ul>
{% endif %}{% endif %}
{% endblock %}

{% block file_sidebar %}
<div id="navcontainer">
    <div id="image_container">
        <img src="{{ original.thumbnails.admin_sidebar_preview }}" alt="{{ original.label }}" rel="{{ adminform.form.sidebar_image_ratio }}" />
        <div id="paper">&nbsp;</div>
    </div>
    <a href="{{ original.url }}">{% trans "Full size preview" %}</a>
</div>
{{ block.super }}
{% endblock %}