
<!DOCTYPE html>
{% load leonardo_tags feincms_page_tags applicationcontent_tags branding i18n %}

<html>
  <head>
    {% include "_header.html" %}
  </head>
  <body id="{% block body_id %}main_content{% endblock %}" ng-app='hz' class="skin-blue">
    {% include "horizon/_messages.html" %}
    {% block body %}{% endblock %}
    {% block body_main %}{% endblock %}
    {% include "leonardo/_footer.html" %}
  </body>
</html>
