{% load i18n %}
{% load url from future %}

{% if edit %}
<div class="clearfix col-md-12 region-tools">
  <a href="{{ widget_add_url }}" class='btn btn-block btn-success ajax-modal' data-toggle="tooltip" data-placement="bottom" title="" data-original-title="Add new widget to region {{ region }} of page {{ feincms_object.title }}.">{% trans 'Add Widget' %}</a>
</div>
{% endif %}