<div class="span-12">
<p>
  <strong>&lt;strong&gt;</strong><br>
  <del>&lt;del&gt; deleted</del><br>
  <dfn>&lt;dfn&gt; dfn</dfn><br>
  <em>&lt;em&gt; emphasis</em>
</p>
<p>
  <a>&lt;a&gt; anchor</a><br>
  <a href="#">&lt;a&gt; a + href</a>
</p>
<p>
  <abbr title="extended abbr text should show when mouse over">&lt;abbr&gt; abbr - extended text when mouseover.</abbr><br>
  <acronym title="extended acronym text should show when mouse over">&lt;acronym&gt; acronym - extended text when mouseover.</acronym>
</p>
<address>
  &lt;address&gt;<br>
  Donald Duck<br>
  Box 555<br>
  Disneyland
</address>
<p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore dolore.</p>
</div>



<div class="span-12 last">
<pre>&lt;pre&gt;
pre  space1
pre  space1
pre    space2
pre    space2
pre tab
pre tab</pre>

<code>&lt;code&gt;
  Not indented
  indent1
  indent1
  indent2
  indent3</code>

<tt>&lt;tt&gt;
  This tt text should be monospaced
  and
  wrap as if
  one line of text
  even though the code has newlines, spaces, and tabs.
  It should be the same size as &lt;p&gt; text.
</tt>
</div>