
@import "_mixins";

@import "_variables";

@import "/bootstrap/scss/bootstrap";

@import "/leonardo/scss/leonardo";
@import "/dashboard/scss/horizon_workflow";
@import "/dashboard/scss/horizon_charts";
@import "/leonardo/scss/loading";

.asteriskField {
    display: none;
}

.text-center > .img-responsive {
  margin: 0 auto;
}
.text-center > .img-responsive {
  margin: 0 auto;
}

.dropdown-submenu {
    position: relative;
}

.dropdown-submenu>.dropdown-menu {
    top: 0;
    left: 100%;
    margin-top: -6px;
    margin-left: -1px;
    -webkit-border-radius: 0 6px 6px 6px;
    -moz-border-radius: 0 6px 6px;
    border-radius: 0 6px 6px 6px;
}

.dropdown-submenu:hover>.dropdown-menu {
    display: block;
}

.dropdown-submenu>a:after {
    display: block;
    content: " ";
    float: right;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
    border-width: 5px 0 5px 5px;
    border-left-color: #ccc;
    margin-top: 5px;
    margin-right: -10px;
}

.dropdown-submenu:hover>a:after {
    border-left-color: #fff;
}

.dropdown-submenu.pull-left {
    float: none;
}

.dropdown-submenu.pull-left>.dropdown-menu {
    left: -100%;
    margin-left: 10px;
    -webkit-border-radius: 6px 0 6px 6px;
    -moz-border-radius: 6px 0 6px 6px;
    border-radius: 6px 0 6px 6px;
}

.carousel-control {
    background-image: none !important;
    background: transparent !important;
    .fa {
        top: 50%;
        position: absolute;
    }
}